pub struct PackageInLockFile {
pub root: bool,
pub name: String,
pub version: String,
pub source: Option<String>,
pub ontology_iri: Option<String>,
pub cksum: Option<String>,
pub dependencies: Vec<String>,
}Expand description
A package in the form to be serialized to or to be deserialized to or from the lock file.
Fields
root: boolname: Stringversion: Stringsource: Option<String>ontology_iri: Option<String>cksum: Option<String>dependencies: Vec<String>Trait Implementations
Sourceimpl Clone for PackageInLockFile
impl Clone for PackageInLockFile
Sourcefn clone(&self) -> PackageInLockFile
fn clone(&self) -> PackageInLockFile
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PackageInLockFile
impl Debug for PackageInLockFile
Sourceimpl<'de> Deserialize<'de> for PackageInLockFile
impl<'de> Deserialize<'de> for PackageInLockFile
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Into<PackageVersion> for &PackageInLockFile
impl Into<PackageVersion> for &PackageInLockFile
Sourcefn into(self) -> PackageVersion
fn into(self) -> PackageVersion
Converts this type into the (usually inferred) input type.
Sourceimpl PartialEq for PackageInLockFile
impl PartialEq for PackageInLockFile
Sourceimpl Serialize for PackageInLockFile
impl Serialize for PackageInLockFile
Sourceimpl<V> TryFrom<&PackageInLockFile> for Dependency<V>
impl<V> TryFrom<&PackageInLockFile> for Dependency<V>
Sourceimpl<V> TryFrom<PackageInLockFile> for Dependency<V>
impl<V> TryFrom<PackageInLockFile> for Dependency<V>
impl Eq for PackageInLockFile
impl StructuralPartialEq for PackageInLockFile